PyISY Constants
===============

Constants used by the PyISY module are derived from `The ISY994 Developer Cookbook <https://www.universal-devices.com/docs/production/The+ISY994+Developer+Cookbook.pdf>`_.

.. automodule:: pyisy.constants
    :members:
